/**
 * Created by jiachenpan on 16/11/18.
 */

function isExternal(path) {
  return /^(https?:|mailto:|tel:)/.test(path)
}

function validUsername(str) {
  const valid_map = ['admin', 'editor']
  return valid_map.indexOf(str.trim()) >= 0
}

/* 合法uri*/
function validURL(url) {
  const reg = /^(https?|ftp):\/\/([a-zA-Z0-9.-]+(:[a-zA-Z0-9.&%$-]+)*@)*((25[0-5]|2[0-4][0-9]|1[0-9]{2}|[1-9][0-9]?)(\.(25[0-5]|2[0-4][0-9]|1[0-9]{2}|[1-9]?[0-9])){3}|([a-zA-Z0-9-]+\.)*[a-zA-Z0-9-]+\.(com|edu|gov|int|mil|net|org|biz|arpa|info|name|pro|aero|coop|museum|[a-zA-Z]{2}))(:[0-9]+)*(\/($|[a-zA-Z0-9.,?'\\+&%$#=~_-]+))*$/
  return reg.test(url)
}

/**中文名 */
function validName(value) {
  const reg = /^[\u4e00-\u9fa5·]{1,20}$/
  return reg.test(value)
}

/**身份证 */
function validId(value) {
  const reg = /(^\d{15}$)|(^\d{18}$)|(^\d{17}(\d|X|x)$)/;
  return reg.test(value)
}

/* 小写字母*/
function validLowerCase(str) {
  const reg = /^[a-z]+$/
  return reg.test(str)
}

/* 大写字母*/
function validUpperCase(str) {
  const reg = /^[A-Z]+$/
  return reg.test(str)
}

/* 大小写字母*/
function validAlphabets(str) {
  const reg = /^[A-Za-z]+$/
  return reg.test(str)
}

/* 电话不能有中文*/
function validCall(str){
  const reg = /[\u4e00-\u9fa5]/
  return !reg.test(str)
}
/**
 * validate email
 * @param email
 * @returns {boolean}
 */
function validEmail(email) {
  const re = /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/
  return re.test(email)
}


function validPrice(value) {
  const re = /(^[1-9]\d*(\.\d{1,2})?$)|(^0(\.\d{1,2})?$)/;
  return re.test(value)
}

/**
 * validate phone
 * @param phone
 * @returns {boolean}
 */
function validPhone(phone) {
  const re = /^1\d{10}$/
  return re.test(phone)
}
/**
 * validate nickName
 * @param nickName
 * @returns {boolean}
 */
function validNickName(nickName) {
  const re = /^[\w\u4e00-\u9fa5]{1,20}$/
  return re.test(nickName)
}

/**
 * validate password
 * @param password
 * @returns {boolean}
 */
function validPassword(password) {
  const re = /^[\@A-Za-z0-9\!\#\$\%\^\&\*\.\~\?_,;:]{6,16}$/
  return re.test(password)
}

/**
 * validate acc
 * @param acc
 * @returns {boolean}
 */
function validAcc(acc) {
  const re = /^[A-Za-z0-9]{3,24}$/
  return re.test(acc)
}


/**
 * validate card
 * @param card
 * @returns {boolean}
 */
function validCard(card) {
  const re = /^[0-9]\d{10,26}$/
  return re.test(card)
}

/**
 * validate no
 * @param card
 * @returns {boolean}
 */
function validCardOn(card) {
  const re = /^[0-9a-zA-Z]{15,15}$|^[0-9a-zA-Z]{18,18}$|^[0-9a-zA-Z]{20,20}$/
  return re.test(card)
}


/**
 * validate no
 * @param card
 * @returns {boolean}
 */
function validIp(ip) {
  const IP_SCOPE_C = /^(25[0-5]|2[0-4]\d|1\d{2}|[1-9]?\d)\.(25[0-5]|2[0-4]\d|1\d{2}|[1-9]?\d)\.(25[0-5]|2[0-4]\d|1\d{2}|[1-9]?\d)\.0\/24$/
  const IP_SCOPE_B = /^(25[0-5]|2[0-4]\d|1\d{2}|[1-9]?\d)\.(25[0-5]|2[0-4]\d|1\d{2}|[1-9]?\d)\.0\.0\/16$/
  const IP = /^(25[0-5]|2[0-4]\d|1\d{2}|[1-9]?\d)\.(25[0-5]|2[0-4]\d|1\d{2}|[1-9]?\d)\.(25[0-5]|2[0-4]\d|1\d{2}|[1-9]?\d)\.(25[0-5]|2[0-4]\d|1\d{2}|[1-9]?\d)$/
  return (IP_SCOPE_C.test(ip) || IP_SCOPE_B.test(ip) || IP.test(ip) )
}



/**
 * 
 * @returns 验证英文
 */
function checkEn(obj){
  if (obj.length != 0) {
    if (obj.match(/^[A-Za-z]+$/))
        return true;
    else
        return false;
  }
}


/**
 * 
 * @returns 验证中文不包含空格
 */
 function checkNameNoSpace(obj){
  if (obj.length != 0) {
    if (obj.match(/^[\u4e00-\u9fa5]+$/))
        return true;
    else
        return false;
  }
}

/**
 * 
 * @returns 验证中文
 */
 function checkName(obj){
  if (obj.length != 0) {
    if (obj.match(/^[\u4e00-\u9fa5]|(\s)+$/))
        return true;
    else
        return false;
  }
}

/**
 * 
 * @returns 验证中文或空格
 */
 function checkNameAndSpace(obj){
  if (obj.length != 0) {
    if (obj.match(/^([\u4e00-\u9fa5])|(\s)+$/))
        return true;
    else
        return false;
  }
}

/**
 * 
 * @returns 验证中文或空格
 */
 function checkNumber(obj){
  if (obj.length != 0) {
    if (obj.match(/^([0-9])+$/))
        return true;
    else
        return false;
  }
}